#!/bin/bash
#
# 08/10/2013 Updated to add detection for tomcat verstion (RA)
# 14/02/2014 Updated to copy cache.xml from old location to new config dir (RA)

source /backups/patch/settings.sh

cleanup() {
 cd $PATCHBASE
 rm -rf *
 rm -rf /tmp/proxy
 echo; echo "Clean up done..."
}

initialise() {
 if test -f /etc/rc.d/init.d/tomcat5; then
  TOMCAT=tomcat5; fi
 if test -f /etc/rc.d/init.d/tomcat; then
  TOMCAT=tomcat; fi
 if test ! $TOMCAT; then
  echo "Unable to detect the version of tomcat installed."
  echo "Exiting..."
  exit; fi
}

appliance_type() {
 PINSAFE_TYPE=`grep PINSAFE_TYPE $PINSAFE_CONF|cut -d\= -f2`

 if test ! $PINSAFE_TYPE; then
  stnd_err "Appliance type is not correctly configured."; fi
 if test "$PINSAFE_TYPE" = "Single"; then
  PINSAFE_TYPE="Single "; fi
}

heading() {
 clear
 echo "${inv} Swivel Maintenance (c) $COPYRIGHT_YEAR${nor}                                             ${inv}$PINSAFE_TYPE${nor}"
 echo
 echo $1
 echo
}

yorn() {
 echo
 echo -n "Are you sure? (Yes/No): "
 read yn
 check_ans $1 $yn
}

check_ans() {
 if test ! $2; then
  $1; fi
 if test ! $2 = "Yes" && test ! $2 = "yes" && test ! $2 = "y" && test ! $2 = "Y" ; then
  $1; fi
}

check_running() {
 if test "`ps -eaf|grep $2|egrep -v "UID|grep|mysqld_safe|alert.d" 2>/dev/null`"; then
  if test ! -f $LOCK/$1; then
   touch $LOCK/$1; fi
 else
  if test -f $LOCK/$1; then
   rm -f $LOCK/$1; fi
 fi

 if test -f $LOCK/$1; then
  value="Running"
 else
  value="Stopped"
 fi
}

show_dots() {
 i=0
 while test $i -lt $1; do
  echo -n "."
  sleep 1 
  ((i = i + 1))
 done
}

service_sands_tomcat() {
 nohup service $TOMCAT $1 > /dev/null 2>&1 &
 echo -n "Tomcat: $1"
 show_dots 4
}

service_sands() {
 service $1 $2
}

warning() {
 heading "Upgrading Swivel Proxy"
 echo "Continuing will apply patch ${inv}Swivel Proxy $PATCH_VER${nor}."
 echo "The Swivel solution cannot be used whilst upgrading."
 echo
 yorn exit
}

appliance_version() {
 APPLIANCE_VERS=`grep ^APPLIANCE_VERS= $PINSAFE_CONF|cut -d\= -f2`
 APPLIANCE_VERS=$(echo $APPLIANCE_VERS|awk -F\. '{print $1$2$3}')
 APPLIANCE_REQUIRED=$(echo $APPLIANCE_REQUIRED|awk -F\. '{print $1$2$3}')

 if test $APPLIANCE_VERS && test $APPLIANCE_REQUIRED; then
  if test $APPLIANCE_VERS -lt $APPLIANCE_REQUIRED; then
   echo "The appliance requires patching before Swivel Proxy can be updated"
   echo; read -p "Press Return to exit" yn
   exit; fi
 else
  echo "Unable to determine appliance version"
  echo; read -p "Press Return to exit" yn
  exit
 fi
}

install_proxy() {
 check_running $TOMCAT tomcat
 if test $value = "Running"; then
  echo "Stopping Tomcat and Swivel service"
  service_sands $TOMCAT stop
 fi
 
 echo "Creating backup of original Swivel proxy to /tmp"
 if test -d $TOMCAT_PATH/webapps2/proxy; then
  cp -rp $TOMCAT_PATH/webapps2/proxy /tmp; fi

 echo "Starting Tomcat and Swivel service"
 service_sands_tomcat start

 echo; echo "Removing old proxy instance, please wait..."
 rm -f $TOMCAT_PATH/webapps2/proxy.war
 sleep 20
 if test -d $TOMCAT_PATH/webapps2/proxy; then
  rm -rf $TOMCAT_PATH/webapps2/proxy; fi 

 echo; echo "Deploying new Swivel Proxy software"
 cp $PATCHBASE/proxy.war $TOMCAT_PATH/webapps2 

 echo "Upgrade complete"
}

appliance_type
heading "Upgrading Swivel Proxy"
initialise
appliance_version
warning
install_proxy
cleanup
echo; read -p "Press Return to continue" yn
